Obtain similarities a vote result shares with other votes
Source:R/similar_votes.R
similar_votes.Rdsimilar_votes allows to obtain correlations of specified vote with other votes.
Arguments
- federalvotes
tibble or data.frame that is returned by 'get_swissvotes'.
- id
identification number of the vote, needs four digits. Vote 626 (Zersiedelungsinitiative) needs 6260.
- corr
set to TRUE by default. If FALSE return the variance-covariance matrix.
- from
lower limit of correlations.
- to
upper limit of correlations.
Examples
# \donttest{
fedvotes <- get_nationalvotes(geolevel = "canton",from_date = "2010-03-07",to_date="2019-02-10")
#Find correlating votes for the 'Zersiedelungsinitiative', 2019-02-10
results <- similar_votes(fedvotes, id=6260)
#Zersiedelungsinitiative, 2019-02-10, filter stronger correlations (>0.5)
results <- similar_votes(fedvotes, id=6260, from = 0.5)
# }