powered by
available_votedates is a utility function to get the available votedates.
available_votedates
available_votedates(geolevel = "national", call_res)
geographical level for which available votedates should be displayed. options "national" or "canton".
result of a previous call to the base API. Optional argument.
a vector of votedates (Format: YYYY-MM-DD)
available_votedates - get available votedates of federal and cantonal popular votes
# NOT RUN { # Get vector of all available dates federal_votedates <- available_votedates() cantonal_votedates <- available_votedates(geolevel = "canton") # }
Run the code above in your browser using DataLab