# NOT RUN {
# Get and transform the json for the most recent vote
results <- canton_json_to_dfr()
# Get and transform the json for a single votedate at counting district level
canton_json_to_dfr(votedate = "2020-02-09", geolevel = "zh_counting_districts")
# }
Run the code above in your browser using DataLab