geographical level. Options: "national", "canton", "district", "municipality", "zh_counting_districts" or "lakes".
latest
if TRUE, the latest data is retrieved. If FALSE, geo data from the beginning of the year is retrieved.
The API does not support finer distinctions. For more detailed information on the exact status of the data, please use
verbode = TRUE.
verbose
if TRUE, the date from which the data originates is displayed.
call_res
result of a previous call to the geodata API. Optional argument.
Value
a simple feature collection of the desired spatial units with corresponding IDs.