Download poll data collected after a national vote by gfs.bern and the political science departements of the universities of Berne, Zurich, and Geneva.
Source:R/get_poll.R
get_poll.Rdget_poll downloads exit poll data Please cite data.
Arguments
- bfsnr
number of identification of the vote, by default = NULL. Polls available after September 2020 (from voteid 6360 onwards). Bfsnr corresponds to anr in swissvotes data and has to be four digits (available through get_swissvotes).
- codebook
by default = FALSE. If TRUE navigates your browser to the codebook if available.