get_swissvotes: Download additional data collected by annee politique suisse (the complete SwissVotes-Database)
Description
get_swissvotes downloads additional data collected by annee politique suisse. It allows for completely downloading their database. Please cite data.
get_swissvotes downloads additional data collected by annee politique suisse. It allows for completely downloading their database. Please cite data.
Usage
get_swissvotes(DB = T, savecitation = F, codebook = F)get_swissvotes(DB = T, savecitation = F, codebook = F)
Arguments
savecitation
by default = FALSE. Saves the citation within a .txt file in the working directory if TRUE.
codebook
by default = FALSE. If TRUE navigates your browser to the codebook.
Value
a tibble containing the results
a tibble containing the results
Details
get_swissvotes - retrieve data on votes. The unit of analysis are votes.
get_swissvotes - retrieve data on votes. The unit of analysis are votes.
Examples
Run this code# NOT RUN {
# See codebook only
get_swissvotes(codebook=FALSE)
# See codebook only
get_swissvotes(codebook=FALSE)
# }
Run the code above in your browser using DataLab